@@ -263,7 +263,6 @@ gnc_book_option_num_field_source_change_cb (gboolean num_action)
     }
     gnc_book_option_num_field_source_change (num_action);
     gnc_resume_gui_refresh ();
-    gnc_gui_refresh_all ();
 }
 
 Account *
@@ -1473,11 +1472,9 @@ xaccSPrintAmount (char * bufp, gnc_numeric val, GNCPrintAmountInfo info)
 
     if (info.commodity && info.use_symbol)
     {
-        if (gnc_commodity_is_iso (info.commodity))
-	    currency_symbol = gnc_commodity_get_nice_symbol (info.commodity);
-        else
+        currency_symbol = gnc_commodity_get_nice_symbol (info.commodity);
+        if (!gnc_commodity_is_iso (info.commodity))
         {
-            currency_symbol = gnc_commodity_get_mnemonic (info.commodity);
             cs_precedes  = FALSE;
             sep_by_space = TRUE;
         }
